package com.webchat.ugc.messaegqueue.service;


import com.google.common.collect.Lists;
import com.webchat.domain.dto.queue.MomentPublishMessageDTO;
import com.webchat.domain.vo.response.moment.MomentVO;
import com.webchat.ugc.service.AccountService;
import com.webchat.ugc.service.chain.MomentImageHandler;
import com.webchat.ugc.service.chain.MomentIpAddressHandler;
import com.webchat.ugc.service.chain.MomentLinkHandler;
import com.webchat.ugc.service.chain.MomentPublishHandlerChain;
import com.webchat.ugc.service.chain.MomentRefreshHandler;
import com.webchat.ugc.service.chain.MomentReviewHandler;
import com.webchat.ugc.service.chain.MomentVideoHandler;
import com.webchat.ugc.service.moment.MomentTimeLineService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

@Service
public class MomentPublishConsumeService {

    @Autowired
    private MomentImageHandler momentImageHandler;
    @Autowired
    private MomentVideoHandler momentVideoHandler;
    @Autowired
    private MomentLinkHandler momentLinkHandler;
    @Autowired
    private MomentReviewHandler momentReviewHandler;
    @Autowired
    private MomentRefreshHandler momentRefreshHandler;
    @Autowired
    private MomentIpAddressHandler momentIpAddressHandler;
    @Autowired
    private AccountService accountService;
    @Autowired
    private MomentTimeLineService momentTimeLineService;

    /**
     * 动态发布后置处理
     * @param dto
     */
    public void consume(MomentVO dto) {

        /**
         * 后置动态数据处理链（应用责任链设计模式）：
         *
         * 1. 图片媒体资源信息提取
         * 2. 视频媒体资源信息提取
         * 3. 连接解析
         * 4. ip归属地解析
         * 5. 大模型内容审核
         * 6. 刷新/修改动态状态
         * ……
         */
        /**
         * 动态发布后置处理任务链
         */
        MomentPublishHandlerChain chain = new MomentPublishHandlerChain();
        chain.addHandler(Lists.newArrayList(momentImageHandler,
                                            momentVideoHandler,
                                            momentLinkHandler,
                                            momentIpAddressHandler,
                                            momentReviewHandler,
                                            momentRefreshHandler)).handle(dto, chain);

        /**
         * 写扩散（把当前动态写入到所有粉丝时间线DB、Redis）
         */
        momentTimeLineService.addTimeLine(dto.getAuthor(), dto.getId(), dto.getPublishTime());
    }

}
